var assert = require('power-assert');
var dtsgenerator = require('../lib/index');
describe('error schema test', function () {
    it('no id schema', function () {
        var schema = { type: 'object' };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('id is not found.', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("id is not found.", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 14
            }));
        }
    });
    it('no type schema', function () {
        var schema = { id: '/test/no_type' };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('unknown type: undefined', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("unknown type: undefined", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 26
            }));
        }
    });
    it('unkown type schema', function () {
        var schema = {
            id: '/test/unkown_type',
            type: 'hoge'
        };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('unknown type: hoge', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("unknown type: hoge", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 39
            }));
        }
    });
    it('unkown type property', function () {
        var schema = {
            id: '/test/unkown_property',
            type: 'object',
            properties: { name: { type: 'fuga' } }
        };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('unknown type: fuga', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("unknown type: fuga", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 57
            }));
        }
    });
    it('target of $ref is not found', function () {
        var schema = {
            id: '/test/target_not_found',
            type: 'object',
            properties: { ref: { $ref: '/notFound/id#' } }
        };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('$ref target is not found: /notFound/id', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("$ref target is not found: /notFound/id", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 75
            }));
        }
    });
    it('target of $ref is invalid path', function () {
        var schema = {
            id: '/test/target_not_found',
            type: 'object',
            properties: { ref: { $ref: '#hogefuga' } }
        };
        try {
            dtsgenerator([schema]);
            assert.fail();
        } catch (e) {
            assert.equal('$ref path must be absolute path: hogefuga', assert._expr(assert._capt(assert._capt(e, 'arguments/1/object').message, 'arguments/1'), {
                content: 'assert.equal("$ref path must be absolute path: hogefuga", e.message)',
                filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/error_case_test.js',
                line: 93
            }));
        }
    });
});
//# sourceMappingURL=error_case_test.js.map