var assert = require('power-assert');
var dtsgenerator = require('../lib/index');
describe('simple schema test', function () {
    it('no property schema', function () {
        var schema = {
            id: '/test/no_prop',
            type: 'object'
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface INoProp {\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 12
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 12
        }), result);
    });
    it('one line schema', function () {
        var schema = {
            id: '/test/one_line',
            type: 'object',
            properties: { name: { type: 'string' } }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface IOneLine {\n' + '    name: string;\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 26
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 26
        }), result);
    });
    it('include array schema', function () {
        var schema = {
            id: '/test/inc_array',
            type: 'object',
            properties: {
                id: { type: 'integer' },
                array: {
                    type: 'array',
                    items: { type: 'string' }
                }
            }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface IIncArray {\n' + '    id: number;\n' + '    array: string[];\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 46
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 46
        }), result);
    });
    it('all simple type schema', function () {
        var schema = {
            id: '/test/all_simple_type',
            type: 'object',
            properties: {
                any: { type: 'any' },
                array: {
                    type: 'array',
                    items: {
                        type: 'array',
                        items: { type: 'string' }
                    }
                },
                boolean: { type: 'boolean' },
                integer: { type: 'integer' },
                null: { type: 'null' },
                number: { type: 'number' },
                object: { type: 'object' },
                string: { type: 'string' }
            }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface IAllSimpleType {\n' + '    any: any;\n' + '    array: string[][];\n' + '    boolean: boolean;\n' + '    integer: number;\n' + '    null: any;\n' + '    number: number;\n' + '    object: {\n' + '    };\n' + '    string: string;\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 87
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 87
        }), result);
    });
    it('inner object schema', function () {
        var schema = {
            id: '/test/inner_object',
            type: 'object',
            properties: {
                title: { type: 'string' },
                options: {
                    type: 'object',
                    properties: {
                        A: { type: 'integer' },
                        B: { type: 'number' },
                        C: { type: 'string' }
                    }
                }
            }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface IInnerObject {\n' + '    title: string;\n' + '    options: {\n' + '      A: number;\n' + '      B: number;\n' + '      C: string;\n' + '    };\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 109
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 109
        }), result);
    });
    it('object array schema', function () {
        var schema = {
            id: '/test/object_array',
            type: 'object',
            properties: {
                array: {
                    type: 'array',
                    items: {
                        type: 'object',
                        properties: {
                            name: { type: 'string' },
                            items: {
                                type: 'array',
                                items: { type: 'string' }
                            }
                        }
                    }
                }
            }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  export interface IObjectArray {\n' + '    array: {\n' + '      name: string;\n' + '      items: string[];\n' + '    }[];\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 135
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 135
        }), result);
    });
    it('root array schema', function () {
        var schema = {
            id: 'test/root/root_array',
            type: 'array',
            items: { type: 'string' }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  module root {\n' + '    export interface IRootArray extends Array<string> {\n' + '    }\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 147
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 147
        }), result);
    });
    it('root any schema', function () {
        var schema = {
            id: 'test/root/root_any',
            type: 'any',
            description: 'This is any type schema'
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  module root {\n' + '    /**\n' + '     * This is any type schema\n' + '     */\n' + '    export interface IRootAny {\n' + '      [name: string]: any; // any\n' + '    }\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 157
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 157
        }), result);
    });
    it('include $ref schema', function () {
        var schema = {
            id: 'test/ref/include_ref',
            type: 'object',
            definitions: { name: { type: 'string' } },
            properties: { 'sub-name': { $ref: '#/definitions/name' } }
        };
        var result = dtsgenerator([schema]);
        var expected = 'declare module test {\n' + '  module ref {\n' + '    export interface IIncludeRef {\n' + '      "sub-name": string;\n' + '    }\n' + '  }\n' + '}\n';
        assert.equal(assert._expr(assert._capt(expected, 'arguments/0'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 176
        }), assert._expr(assert._capt(result, 'arguments/1'), {
            content: 'assert.equal(expected, result, result)',
            filepath: '/Users/horiuchihiroki/work/typescript/dtsgenerator/test/simple_schema_test.js',
            line: 176
        }), result);
    });
});
//# sourceMappingURL=simple_schema_test.js.map